@@ -18,25 +18,6 @@ from pqdm.processes import pqdm as ppqdm
 import multiprocessing as mp
 #from pqdm.processes import pqdm
 
-
-def my_parallel(f, arr, n_jobs=None, desc=None):
-    """
-    Parallel execution of f on each element of args
-
-    Examples
-    --------
-    >>> my_parallel(lambda x : x**2, range(0,5))
-    [0, 1, 4, 9, 16]
-
-    """
-    n_jobs = n_jobs or mp.cpu_count()
-    sa = np.array_split(np.array(arr), len(arr) / n_jobs)
-    res = []
-    for i in tqdm.tqdm(range(len(sa)), desc=desc):
-        res += par(f, sa[i])
-    return res
-
-
 class RunParam(DictData):
     """Abstract class that is similar to a dictionary but with fixed keys."""
 
@@ -100,15 +81,16 @@ class Runner:
 
     def _prepare(self, p: Input, skip=False, assume_valid = False, **kwargs) -> RunParam:
         skip_ = skip
+        #p.runner = str(type(self).__name__) + "-" + self.get_version()
+
         d = p.__dict__
-        d["runner"] = str(type(self).__name__) + "-" + self.get_version(
-        )  # TODO re add version, but removed for reusable hashing!
+        #d["runner"] = str(type(self).__name__) + "-" + self.get_version(
+        #)  # TODO re add version, but removed for reusable hashing!
         name = namehash("_".join("".join(str(_[0]) + "_" + str(_[1]))
                                  for _ in d.items()).replace("/", "-"))
         #print(name)
         skip = False
-        if skip_ and os.path.isfile(self.get_output_dir() + name +
-                                    ".out") and (assume_valid or self._is_valid(
+        if skip_ and os.path.isfile(self.get_output_dir() + name + ".out") and (assume_valid or self._is_valid(
                                         self.get_output_dir() + name + ".out",
                                         p,
                                         d,
@@ -117,8 +99,9 @@ class Runner:
             #print(".", end='')
             skip = True
         else:
+            #print(str(self.get_output_dir()  + name + ".out")) 
             #print('|', end='')
-            pass
+            skip = False
         return RunParam(execute=self.get_output_dir() + name + ".sh",
                         in_file=self.get_output_dir() + name + ".in",
                         out_file=self.get_output_dir() + name + ".out",
@@ -160,6 +143,8 @@ class Runner:
         #    params,
         #    #n_jobs=mp.cpu_count(),
         #    desc="Preparing")
+        runnername = str(type(self).__name__) + "-" + self.get_version()
+        for p in params: p.runner = runnername
         args = [{'p': p, 'skip': skip, **kwargs} for p in params]
         ret = ppqdm(args,
                     self._prepare,
