@@ -5,7 +5,8 @@ import numpy as np
 import hashlib
 from particle.converters.bimap import DirectionalMaps
 from particle import PDGID
-import lhapdf
+from distutils.version import StrictVersion
+
 import pandas as pd
 import warnings
 from smpl import interpolate as ip
@@ -156,11 +157,35 @@ def lhapdf_name_to_id(name: str) -> int:
         >>> lhapdf_name_to_id("CT14lo")
         13200
     """
+    try:
+        import lhapdf
+    except ImportError:
+        warnings.warn("LHAPDF python binding not installed? Make sure you set PYTHONPATH correctly (i.e. correct python version).")
+        return 0
+    if not lhapdf.availablePDFSets():
+        warnings.warn("No PDF sets found. Make sure the environment variable LHAPDF_DATA_DIR points to the correct location (.../share/LHAPDF).")
+        return 0
     if not name in lhapdf.availablePDFSets():
-        warnings.warn("PDF set '" + name + "' not installed!")
+        warnings.warn("PDF set '" + name + "' not installed?")
         return 0
     return lhapdf.getPDFSet(name).lhapdfID
 
+def lhapdf_id_to_name(lid : int) -> str:
+    try:
+        import lhapdf
+    except ImportError:
+        warnings.warn("LHAPDF python binding not installed? Make sure you set PYTHONPATH correctly (i.e. correct python version).")
+        return ""
+    if not lhapdf.availablePDFSets():
+        warnings.warn("No PDF sets found. Make sure the environment variable LHAPDF_DATA_DIR points to the correct location (.../share/LHAPDF).")
+        return 0
+    for n in lhapdf.availablePDFSets():
+        if lhapdf.getPDFSet(n).lhapdfID == lid:
+            return n
+        
+    warnings.warn("PDF set with id " + str(lid) + " unknown/not installed?")
+    return "Unknown PDF ID: " + str(lid)
+
 # TODO fix dependent(mu) for new masses
 
 def interpolate_1d(df,x,y,xrange,only_interpolation=True):
@@ -203,4 +228,4 @@ def interpolate_2d(df,x,y,z,xrange,yrange,only_interpolation=True,**kwargs):
     if only_interpolation:
         return pd.concat(a)
     else:
-        return pd.concat([df, *a])
\ No newline at end of file
+        return pd.concat([df, *a])
